# autodeploy_template/__init__.py
# from <parent_folder>.<python_file> import (
#     <every_class>, 
#     <every_function>, 
#     <every_variable>,
# )

# import upload_package.upload as upload
import robin_sd_upload.module_1 as module_1

module_1.bar()
print(module_1.variable)



import os
import yaml
import validators

def parse_config(config_file):

    contents = {
        "robin_email": "your email address",
        "robin_password": "your password",
        "api_url": "api url"
    }

    if os.path.isfile(config_file):
        print("Config file exists at " + config_file)
        with open(config_file, "r") as stream:
            try:
                config = yaml.safe_load(stream)
                # Validate types
                if type(config['robin_email']) is not str:
                    print("robin_email is not a string")
                    exit(1)
                if type(config['robin_password']) is not str:
                    print("robin_password is not a string")
                    exit(1)
                if not validators.url(config['api_url']):
                    print("api_url is not a valid URL")
                    exit(1)
                # if type(config['filepath']) is not str:
                #     print("filepath is not a string")
                #     exit(1)
                return config
            except yaml.YAMLError as exc:
                print(exc)

    else:
        print("Config file does not exist, creating it at " + config_file)
        # create the directory if it doesn't exist
        os.makedirs(os.path.dirname(config_file), exist_ok=True)
        # write the config file
        with open(config_file, "w") as stream:
            yaml.dump(contents, stream)
        print("Config file created at " + config_file)
        exit(1)


import requests

def get_bearer_token(config):
    email_add = config['robin_email']
    password = config['robin_password']
    request_url = config['api_url']

    headers = {
        'Content-Type': 'application/json',
    }

    data = '{"email": "' + email_add + '", "password": "' + password + '"}'
    response = requests.post(request_url + '/api/auth/login', headers=headers, data=data)

    if response.status_code == 200:
        bearer_token = response.json()['token']
        return bearer_token
    else:
        print("Error getting bearer token")
        return 1



import os

def create_folder(folder):
    if not os.path.exists(folder):
        os.makedirs(folder)
        print("Folder created: " + folder)
        print("Folder path: " + os.path.abspath(folder))
        print('try to run script again')
        exit()
    else:
        print("Folder exists: " + folder)


import os
import argparse
import yaml
from .validate import validate
from .create_zip import create_zip
from .push_software import push_software
from .remove_zip import remove_zip
from .parse_config import parse_config
from .check_upload_file import check_upload_file

def arg_parse(config_file):
    parser = argparse.ArgumentParser(
        description = 'Robin Radar Systems Software Uploader',
        usage       = 'robin-sd-upload [options]', 
        prog        = 'Robin Radar Systems Software Uploader',
        epilog      = 'To report any bugs or issues, please visit: https://support.robinradar.systems'
    )

    parser.add_argument('--check', action='store_true', help='ensure all prerequisites are met')
    parser.add_argument('--upload', action='store_true', help='upload software: robin-sd-upload --upload --type=radar_type --version=version_name --source=upload_file_absolute_path')
    # arguments for upload
    parser.add_argument("--type", type=str, help="radar type")
    parser.add_argument("--version", type=str, help="version name")
    parser.add_argument("--source", type=str, help="upload file absolute path")

    args = parser.parse_args()
    radarType = args.type
    version_name = args.version
    upload_file_path = args.source

    if args.check:
        parse_config(config_file)
        exit(0)
    elif args.upload:
        #check if type,version,source are given
        if radarType is None or version_name is None or upload_file_path is None:
            print('Please provide all the arguments: --type, --version, --source')
            exit(1)
        parse_config(config_file)
        validate(radarType, version_name)
        check_upload_file(upload_file_path)

        version_dir_to_upload= os.path.join(upload_file_path, version_name)
        zipped_file_path = os.path.join(upload_file_path, version_name + '.zip')

        print('version_dir_to_upload: ', version_dir_to_upload)
        print('zipped_file_path: ', zipped_file_path)

        create_zip(zipped_file_path, version_name)
        push_software(config_file, zipped_file_path, radarType, version_name)
        remove_zip(zipped_file_path)
    else:
        parser.print_help()
        exit(1)








def bar():
    print("This function is defined in module_1.py and can be called from any module in the package.")

variable = "This variable is defined in module_1.py and can be accessed from any module in the package."



import os

def check_upload_file(upload_file):
    # convert user file input path to path
    upload_file = os.path.abspath(upload_file)
    print ("Checking if upload file exists: " + upload_file)
    if os.path.isfile(upload_file):
        print("File exists: " + upload_file)
    else:
        return "File not exist: " + upload_file + " - please upload a software version first"
